@@ -91,7 +91,7 @@ def _generateCLIParser() -> ArgumentParser:
     parser.add_argument("--log-file", help="Redirect logs to the given file instead of stderr")
     parser.add_argument(
         "--trace-file",
-        help="Save RPC data to FILE.in and FILE.out (overrides :envvar:`GHDL_LS_TRACE`)",
+        help="Save RPC data to FILE.in and FILE.out (overrides GHDL_LS_TRACE)",
     )
     parser.add_argument("--input", "-i", help="Read request from file")
     parser.add_argument(
