@@ -49,6 +49,7 @@ from pyVHDLModel.Sequential import CaseStatement as VHDLModel_CaseStatement
 from pyVHDLModel.Sequential import ForLoopStatement as VHDLModel_ForLoopStatement
 from pyVHDLModel.Sequential import NullStatement as VHDLModel_NullStatement
 from pyVHDLModel.Sequential import WaitStatement as VHDLModel_WaitStatement
+from pyVHDLModel.Sequential import ExitStatement as VHDLModel_ExitStatement
 from pyVHDLModel.Sequential import SequentialProcedureCall as VHDLModel_SequentialProcedureCall
 from pyVHDLModel.Sequential import SequentialSimpleSignalAssignment as VHDLModel_SequentialSimpleSignalAssignment
 from pyVHDLModel.Sequential import SequentialReportStatement as VHDLModel_SequentialReportStatement
@@ -57,19 +58,18 @@ from pyVHDLModel.Sequential import SequentialAssertStatement as VHDLModel_Sequen
 from pyGHDL.libghdl import Iir, utils
 from pyGHDL.libghdl.vhdl import nodes
 from pyGHDL.dom import DOMMixin, Position, DOMException
-from pyGHDL.dom._Utils import GetNameOfNode
 from pyGHDL.dom.Range import Range
 from pyGHDL.dom.Concurrent import WaveformElement, ParameterAssociationItem  # TODO: move out from concurrent?
 
 
 @export
-class IfBranch(VHDLModel_IfBranch):
+class IfBranch(VHDLModel_IfBranch, DOMMixin):
     def __init__(
         self,
         branchNode: Iir,
         condition: ExpressionUnion,
         statements: Iterable[SequentialStatement] = None,
-    ):
+    ) -> None:
         super().__init__(condition, statements)
         DOMMixin.__init__(self, branchNode)
 
@@ -88,13 +88,13 @@ class IfBranch(VHDLModel_IfBranch):
 
 
 @export
-class ElsifBranch(VHDLModel_ElsifBranch):
+class ElsifBranch(VHDLModel_ElsifBranch, DOMMixin):
     def __init__(
         self,
         branchNode: Iir,
         condition: ExpressionUnion,
         statements: Iterable[SequentialStatement] = None,
-    ):
+    ) -> None:
         super().__init__(condition, statements)
         DOMMixin.__init__(self, branchNode)
 
@@ -113,12 +113,12 @@ class ElsifBranch(VHDLModel_ElsifBranch):
 
 
 @export
-class ElseBranch(VHDLModel_ElseBranch):
+class ElseBranch(VHDLModel_ElseBranch, DOMMixin):
     def __init__(
         self,
         branchNode: Iir,
         statements: Iterable[SequentialStatement] = None,
-    ):
+    ) -> None:
         super().__init__(statements)
         DOMMixin.__init__(self, branchNode)
 
@@ -143,7 +143,7 @@ class IfStatement(VHDLModel_IfStatement, DOMMixin):
         elsifBranches: Iterable[ElsifBranch] = None,
         elseBranch: ElseBranch = None,
         label: str = None,
-    ):
+    ) -> None:
         super().__init__(ifBranch, elsifBranches, elseBranch, label)
         DOMMixin.__init__(self, ifNode)
 
@@ -171,14 +171,14 @@ class IfStatement(VHDLModel_IfStatement, DOMMixin):
 
 @export
 class IndexedChoice(VHDLModel_IndexedChoice, DOMMixin):
-    def __init__(self, node: Iir, expression: ExpressionUnion):
+    def __init__(self, node: Iir, expression: ExpressionUnion) -> None:
         super().__init__(expression)
         DOMMixin.__init__(self, node)
 
 
 @export
 class RangedChoice(VHDLModel_RangedChoice, DOMMixin):
-    def __init__(self, node: Iir, rng: Range):
+    def __init__(self, node: Iir, rng: Range) -> None:
         super().__init__(rng)
         DOMMixin.__init__(self, node)
 
@@ -190,7 +190,7 @@ class Case(VHDLModel_Case, DOMMixin):
         node: Iir,
         choices: Iterable[SequentialChoice],
         statements: Iterable[SequentialStatement] = None,
-    ):
+    ) -> None:
         super().__init__(choices, statements)
         DOMMixin.__init__(self, node)
 
@@ -210,7 +210,7 @@ class OthersCase(VHDLModel_OthersCase, DOMMixin):
         self,
         caseNode: Iir,
         statements: Iterable[SequentialStatement] = None,
-    ):
+    ) -> None:
         super().__init__(statements)
         DOMMixin.__init__(self, caseNode)
 
@@ -236,7 +236,7 @@ class CaseStatement(VHDLModel_CaseStatement, DOMMixin):
         label: str,
         expression: ExpressionUnion,
         cases: Iterable[SequentialCase],
-    ):
+    ) -> None:
         super().__init__(expression, cases, label)
         DOMMixin.__init__(self, caseNode)
 
@@ -246,7 +246,7 @@ class CaseStatement(VHDLModel_CaseStatement, DOMMixin):
         from pyGHDL.dom._Translate import (
             GetExpressionFromNode,
             GetRangeFromNode,
-            GetNameFromNode,
+            GetName,
         )
 
         expression = GetExpressionFromNode(nodes.Get_Expression(caseNode))
@@ -280,7 +280,7 @@ class CaseStatement(VHDLModel_CaseStatement, DOMMixin):
                     nodes.Iir_Kind.Attribute_Name,
                     nodes.Iir_Kind.Parenthesis_Name,
                 ):
-                    rng = GetNameFromNode(choiceRange)
+                    rng = GetName(choiceRange)
                 else:
                     pos = Position.parse(alternative)
                     raise DOMException(
@@ -329,17 +329,17 @@ class ForLoopStatement(VHDLModel_ForLoopStatement, DOMMixin):
         rng: Range,
         statements: Iterable[SequentialStatement] = None,
         label: str = None,
-    ):
+    ) -> None:
         super().__init__(loopIndex, rng, statements, label)
         DOMMixin.__init__(self, loopNode)
 
     @classmethod
     def parse(cls, loopNode: Iir, label: str) -> "ForLoopStatement":
-        from pyGHDL.dom._Utils import GetIirKindOfNode
+        from pyGHDL.dom._Utils import GetNameOfNode, GetIirKindOfNode
         from pyGHDL.dom._Translate import (
             GetSequentialStatementsFromChainedNodes,
             GetRangeFromNode,
-            GetNameFromNode,
+            GetName,
         )
 
         spec = nodes.Get_Parameter_Specification(loopNode)
@@ -353,7 +353,7 @@ class ForLoopStatement(VHDLModel_ForLoopStatement, DOMMixin):
             nodes.Iir_Kind.Attribute_Name,
             nodes.Iir_Kind.Parenthesis_Name,
         ):
-            rng = GetNameFromNode(discreteRange)
+            rng = GetName(discreteRange)
         else:
             pos = Position.parse(loopNode)
             raise DOMException(
@@ -374,16 +374,16 @@ class SequentialSimpleSignalAssignment(VHDLModel_SequentialSimpleSignalAssignmen
         target: Symbol,
         waveform: Iterable[WaveformElement],
         label: str = None,
-    ):
+    ) -> None:
         super().__init__(target, waveform, label)
         DOMMixin.__init__(self, assignmentNode)
 
     @classmethod
     def parse(cls, assignmentNode: Iir, label: str = None) -> "SequentialSimpleSignalAssignment":
-        from pyGHDL.dom._Translate import GetNameFromNode
+        from pyGHDL.dom._Translate import GetName
 
         target = nodes.Get_Target(assignmentNode)
-        targetName = GetNameFromNode(target)
+        targetName = GetName(target)
 
         waveform = []
         for wave in utils.chain_iter(nodes.Get_Waveform_Chain(assignmentNode)):
@@ -400,18 +400,18 @@ class SequentialProcedureCall(VHDLModel_SequentialProcedureCall, DOMMixin):
         procedureName: Symbol,
         parameterMappings: Iterable[ParameterAssociationItem],
         label: str = None,
-    ):
+    ) -> None:
         super().__init__(procedureName, parameterMappings, label)
         DOMMixin.__init__(self, callNode)
 
     @classmethod
     def parse(cls, callNode: Iir, label: str) -> "SequentialProcedureCall":
-        from pyGHDL.dom._Translate import GetNameFromNode, GetParameterMapAspect
+        from pyGHDL.dom._Translate import GetName, GetParameterMapAspect
 
         cNode = nodes.Get_Procedure_Call(callNode)
 
         prefix = nodes.Get_Prefix(cNode)
-        procedureName = GetNameFromNode(prefix)
+        procedureName = GetName(prefix)
         parameterAssociations = GetParameterMapAspect(nodes.Get_Parameter_Association_Chain(cNode))
 
         return cls(callNode, procedureName, parameterAssociations, label)
@@ -426,7 +426,7 @@ class SequentialAssertStatement(VHDLModel_SequentialAssertStatement, DOMMixin):
         message: ExpressionUnion = None,
         severity: ExpressionUnion = None,
         label: str = None,
-    ):
+    ) -> None:
         super().__init__(condition, message, severity, label)
         DOMMixin.__init__(self, assertNode)
 
@@ -451,7 +451,7 @@ class SequentialReportStatement(VHDLModel_SequentialReportStatement, DOMMixin):
         message: ExpressionUnion,
         severity: ExpressionUnion = None,
         label: str = None,
-    ):
+    ) -> None:
         super().__init__(message, severity, label)
         DOMMixin.__init__(self, reportNode)
 
@@ -472,11 +472,23 @@ class NullStatement(VHDLModel_NullStatement, DOMMixin):
         self,
         waitNode: Iir,
         label: str = None,
-    ):
+    ) -> None:
         super().__init__(label)
         DOMMixin.__init__(self, waitNode)
 
 
+@export
+class ExitStatement(VHDLModel_ExitStatement, DOMMixin):
+    def __init__(
+        self,
+        exitNode: Iir,
+        label: str = None,
+    ) -> None:
+        super().__init__(condition=None, loopLabel=label)
+        DOMMixin.__init__(self, exitNode)
+        # TODO: parse condition
+
+
 @export
 class WaitStatement(VHDLModel_WaitStatement, DOMMixin):
     def __init__(
@@ -486,7 +498,7 @@ class WaitStatement(VHDLModel_WaitStatement, DOMMixin):
         condition: ExpressionUnion = None,
         timeout: ExpressionUnion = None,
         label: str = None,
-    ):
+    ) -> None:
         super().__init__(sensitivityList, condition, timeout, label)
         DOMMixin.__init__(self, waitNode)
 
