@@ -30,8 +30,12 @@
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 # ============================================================================
+"""
+This module implements derived type classes from :mod:`pyVHDLModel.Type`.
+"""
 from typing import List, Union, Iterator, Tuple, Iterable
 
+from pyGHDL.dom.Name import SimpleName
 from pyTooling.Decorators import export
 
 from pyVHDLModel.Name import Name
@@ -61,8 +65,8 @@ from pyGHDL.dom.Subprogram import Function, Procedure
 
 @export
 class IncompleteType(VHDLModel_AnonymousType, DOMMixin):
-    def __init__(self, node: Iir, identifier: str):
-        super().__init__(identifier)
+    def __init__(self, node: Iir, identifier: str) -> None:
+        super().__init__(identifier, parent=None)
         DOMMixin.__init__(self, node)
 
     @classmethod
@@ -76,12 +80,31 @@ class IncompleteType(VHDLModel_AnonymousType, DOMMixin):
 
 @export
 class EnumeratedType(VHDLModel_EnumeratedType, DOMMixin):
-    def __init__(self, node: Iir, identifier: str, literals: List[EnumerationLiteral]):
-        super().__init__(identifier, literals)
+    """
+    Represents an *enumerated type*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.EnumeratedType`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type integer is (lit_1, lit2, ...);
+    """
+
+    def __init__(self, node: Iir, identifier: str, literals: List[EnumerationLiteral]) -> None:
+        super().__init__(identifier, literals, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, typeName: str, typeDefinitionNode: Iir) -> "EnumeratedType":
+        """
+        Parses an *enumerated type* IIR and returns an :class:`~pyVHDLModel.Type.EnumeratedType` instance.
+
+        :param typeName:           The identifier of the type.
+        :param typeDefinitionNode: The IIR node to parse.
+        :return:                   The enumerated type instance.
+        """
         literals = []
         enumerationLiterals = nodes.Get_Enumeration_Literal_List(typeDefinitionNode)
         for enumerationLiteral in utils.flist_iter(enumerationLiterals):
@@ -93,13 +116,41 @@ class EnumeratedType(VHDLModel_EnumeratedType, DOMMixin):
 
 @export
 class IntegerType(VHDLModel_IntegerType, DOMMixin):
-    def __init__(self, node: Iir, typeName: str, rng: Union[Range, "Name"]):
-        super().__init__(typeName, rng)
+    """
+    Represents an *integer type*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.IntegerType`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type integer is range -2147483648 to 2147483647;
+    """
+
+    def __init__(self, node: Iir, typeName: str, rng: Union[Range, "Name"]) -> None:
+        super().__init__(typeName, rng, None)
         DOMMixin.__init__(self, node)
 
 
 @export
 class PhysicalType(VHDLModel_PhysicalType, DOMMixin):
+    """
+    Represents a *physical type*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.PhysicalType`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type time is range integer'low to integer'high units
+            fs;
+            ps = 1000 fs;
+            -- ...
+          end units;
+    """
+
     def __init__(
         self,
         node: Iir,
@@ -107,14 +158,21 @@ class PhysicalType(VHDLModel_PhysicalType, DOMMixin):
         rng: Union[Range, Name],
         primaryUnit: str,
         units: List[Tuple[str, PhysicalIntegerLiteral]],
-    ):
-        super().__init__(typeName, rng, primaryUnit, units)
+    ) -> None:
+        super().__init__(typeName, rng, primaryUnit, units, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, typeName: str, typeDefinitionNode: Iir) -> "PhysicalType":
+        """
+        Parses an *physical type* IIR and returns an :class:`~pyVHDLModel.Type.PhysicalType` instance.
+
+        :param typeName:           The identifier of the type.
+        :param typeDefinitionNode: The IIR node to parse.
+        :return:                   The physical type instance.
+        """
         from pyGHDL.dom._Utils import GetIirKindOfNode, GetNameOfNode
-        from pyGHDL.dom._Translate import GetRangeFromNode, GetNameFromNode
+        from pyGHDL.dom._Translate import GetRangeFromNode, GetName
 
         rangeConstraint = nodes.Get_Range_Constraint(typeDefinitionNode)
         rangeKind = GetIirKindOfNode(rangeConstraint)
@@ -124,7 +182,7 @@ class PhysicalType(VHDLModel_PhysicalType, DOMMixin):
             nodes.Iir_Kind.Attribute_Name,
             nodes.Iir_Kind.Parenthesis_Name,
         ):
-            rng = GetNameFromNode(rangeConstraint)
+            rng = GetName(rangeConstraint)
         else:
             pos = Position.parse(typeDefinitionNode)
             raise DOMException(f"Unknown range kind '{rangeKind.name}' in physical type definition at line {pos.Line}.")
@@ -147,12 +205,31 @@ class PhysicalType(VHDLModel_PhysicalType, DOMMixin):
 
 @export
 class ArrayType(VHDLModel_ArrayType, DOMMixin):
-    def __init__(self, node: Iir, identifier: str, indices: List, elementSubtype: Symbol):
-        super().__init__(identifier, indices, elementSubtype)
+    """
+    Represents an *array type*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.ArrayType`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type bit_vector is array(natural range <>) of bit;
+    """
+
+    def __init__(self, node: Iir, identifier: str, indices: List, elementSubtype: Symbol) -> None:
+        super().__init__(identifier, indices, elementSubtype, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, typeName: str, typeDefinitionNode: Iir) -> "ArrayType":
+        """
+        Parses an *array type* IIR and returns an :class:`~pyVHDLModel.Type.ArrayType` instance.
+
+        :param typeName:           The identifier of the type.
+        :param typeDefinitionNode: The IIR node to parse.
+        :return:                   The array type instance.
+        """
         from pyGHDL.dom._Utils import GetIirKindOfNode
         from pyGHDL.dom._Translate import (
             GetSimpleTypeFromNode,
@@ -179,12 +256,34 @@ class ArrayType(VHDLModel_ArrayType, DOMMixin):
 
 @export
 class RecordTypeElement(VHDLModel_RecordTypeElement, DOMMixin):
-    def __init__(self, node: Iir, identifiers: List[str], subtype: Symbol):
-        super().__init__(identifiers, subtype)
+    """
+    Represents a *record element*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.RecordTypeElement`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          -- type pt is record
+            element : std_logic;
+            -- ...
+          -- end record;
+    """
+
+    def __init__(self, node: Iir, identifiers: List[str], subtype: Symbol) -> None:
+        super().__init__(identifiers, subtype, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, elementDeclarationNode: Iir, furtherIdentifiers: Iterable[str] = None) -> "RecordTypeElement":
+        """
+        Parses a *record element* IIR and returns an :class:`~pyVHDLModel.Type.RecordTypeElement` instance.
+
+        :param elementDeclarationNode: The IIR node to parse.
+        :param furtherIdentifiers:     The list of record element identifiers.
+        :return:                       The record element instance.
+        """
         from pyGHDL.dom._Utils import GetNameOfNode
         from pyGHDL.dom._Translate import GetSubtypeIndicationFromNode
 
@@ -200,12 +299,33 @@ class RecordTypeElement(VHDLModel_RecordTypeElement, DOMMixin):
 
 @export
 class RecordType(VHDLModel_RecordType, DOMMixin):
-    def __init__(self, node: Iir, identifier: str, elements: List[RecordTypeElement] = None):
-        super().__init__(identifier, elements)
+    """
+    Represents a *record type*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.RecordType`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type pt is record
+            -- elements
+          end record;
+    """
+
+    def __init__(self, node: Iir, identifier: str, elements: List[RecordTypeElement] = None) -> None:
+        super().__init__(identifier, elements, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, typeName: str, typeDefinitionNode: Iir) -> "RecordType":
+        """
+        Parses a *record type* IIR and returns an :class:`~pyVHDLModel.Type.RecordType` instance.
+
+        :param typeName:           The identifier of the type.
+        :param typeDefinitionNode: The IIR node to parse.
+        :return:                   The record type instance.
+        """
         from pyGHDL.dom._Utils import GetNameOfNode
 
         elements = []
@@ -244,12 +364,33 @@ class RecordType(VHDLModel_RecordType, DOMMixin):
 
 @export
 class ProtectedType(VHDLModel_ProtectedType, DOMMixin):
-    def __init__(self, node: Iir, identifier: str, methods: Union[List, Iterator] = None):
-        super().__init__(identifier, methods)
+    """
+    Represents a *protected type*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.ProtectedType`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type pt is protected
+            -- public interface
+          end protected;
+    """
+
+    def __init__(self, node: Iir, identifier: str, methods: Union[List, Iterator] = None) -> None:
+        super().__init__(identifier, methods, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, typeName: str, typeDefinitionNode: Iir) -> "ProtectedType":
+        """
+        Parses a *protected type* IIR and returns an :class:`~pyVHDLModel.Type.ProtectedType` instance.
+
+        :param typeName:           The identifier of the type.
+        :param typeDefinitionNode: The IIR node to parse.
+        :return:                   The protected type instance.
+        """
         from pyGHDL.dom._Utils import GetIirKindOfNode
 
         # FIXME: change this to a generator
@@ -266,12 +407,32 @@ class ProtectedType(VHDLModel_ProtectedType, DOMMixin):
 
 @export
 class ProtectedTypeBody(VHDLModel_ProtectedTypeBody, DOMMixin):
-    def __init__(self, node: Iir, identifier: str, declaredItems: Union[List, Iterator] = None):
-        super().__init__(identifier, declaredItems)
+    """
+    Represents a *protected type body*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.ProtectedTypeBody`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type pt is protected body
+            -- implementations
+          end protected body;
+    """
+
+    def __init__(self, node: Iir, identifier: str, declaredItems: Union[List, Iterator] = None) -> None:
+        super().__init__(identifier, declaredItems, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, protectedBodyNode: Iir) -> "ProtectedTypeBody":
+        """
+        Parses a *protected type body* IIR and returns an :class:`~pyVHDLModel.Type.ProtectedTypeBody` instance.
+
+        :param protectedBodyNode: The IIR node to parse.
+        :return:                  The protected type body instance.
+        """
         from pyGHDL.dom._Utils import GetNameOfNode
         from pyGHDL.dom._Translate import GetDeclaredItemsFromChainedNodes
 
@@ -287,12 +448,31 @@ class ProtectedTypeBody(VHDLModel_ProtectedTypeBody, DOMMixin):
 
 @export
 class AccessType(VHDLModel_AccessType, DOMMixin):
-    def __init__(self, node: Iir, identifier: str, designatedSubtype: Symbol):
-        super().__init__(identifier, designatedSubtype)
+    """
+    Represents an *access type*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.AccessType`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type line is access string;
+    """
+
+    def __init__(self, node: Iir, identifier: str, designatedSubtype: Symbol) -> None:
+        super().__init__(identifier, designatedSubtype, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, typeName: str, typeDefinitionNode: Iir) -> "AccessType":
+        """
+        Parses an *access type* IIR and returns an :class:`~pyVHDLModel.Type.AccessType` instance.
+
+        :param typeName:           The identifier of the type.
+        :param typeDefinitionNode: The IIR node to parse.
+        :return:                   The access type instance.
+        """
         from pyGHDL.dom._Translate import GetSubtypeIndicationFromIndicationNode
 
         designatedSubtypeIndication = nodes.Get_Designated_Subtype_Indication(typeDefinitionNode)
@@ -303,23 +483,50 @@ class AccessType(VHDLModel_AccessType, DOMMixin):
 
 @export
 class FileType(VHDLModel_FileType, DOMMixin):
-    def __init__(self, node: Iir, identifier: str, designatedSubtype: Symbol):
-        super().__init__(identifier, designatedSubtype)
+    """
+    Represents a *file type*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.FileType`.
+
+    .. admonition:: Example
+
+       .. code-block:: VHDL
+
+          type text is file of string;
+    """
+
+    def __init__(self, node: Iir, identifier: str, designatedSubtype: Symbol) -> None:
+        super().__init__(identifier, designatedSubtype, None)
         DOMMixin.__init__(self, node)
 
     @classmethod
     def parse(cls, typeName: str, typeDefinitionNode: Iir) -> "FileType":
+        """
+        Parses a *file type* IIR and returns an :class:`~pyVHDLModel.Type.FileType` instance.
+
+        :param typeName:           The identifier of the type.
+        :param typeDefinitionNode: The IIR node to parse.
+        :return:                   The file type instance.
+        """
         from pyGHDL.dom._Utils import GetNameOfNode
 
         designatedSubtypeMark = nodes.Get_File_Type_Mark(typeDefinitionNode)
         designatedSubtypeName = GetNameOfNode(designatedSubtypeMark)
-        designatedSubtype = SimpleSubtypeSymbol(typeDefinitionNode, designatedSubtypeName)
+        designatedSubtype = SimpleSubtypeSymbol(
+            typeDefinitionNode, SimpleName(designatedSubtypeMark, designatedSubtypeName)
+        )
 
         return cls(typeDefinitionNode, typeName, designatedSubtype)
 
 
 @export
 class Subtype(VHDLModel_Subtype, DOMMixin):
-    def __init__(self, node: Iir, subtypeName: str):
-        super().__init__(subtypeName)
+    """
+    Represents a *subtype*.
+
+    This class implements a :mod:`pyGHDL.dom` object derived from :class:`pyVHDLModel.Type.Subtype`.
+    """
+
+    def __init__(self, node: Iir, subtypeName: str, symbol: Symbol) -> None:
+        super().__init__(subtypeName, symbol, None)
         DOMMixin.__init__(self, node)
