@@ -9,8 +9,6 @@
 # Authors:
 #   Patrick Lehmann
 #
-# Package package:  Document object model (DOM) for pyGHDL.libghdl.
-#
 # License:
 # ============================================================================
 #  Copyright (C) 2019-2021 Tristan Gingold
@@ -30,27 +28,29 @@
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 # ============================================================================
+"""
+Document object model (DOM) for :mod:`pyGHDL.libghdl` based on :doc:`pyVHDLModel <vhdlmodel:index>`.
+"""
 from pathlib import Path
 
-from pyTooling.Decorators import export
+from pyTooling.Decorators import export, readonly
+from pyTooling.MetaClasses import ExtendedType
 
 from pyGHDL import GHDLBaseException
 from pyGHDL.libghdl import files_map, name_table
 from pyGHDL.libghdl._types import Iir
 from pyGHDL.libghdl.vhdl import nodes
 
-__all__ = []
-
 
 @export
-class Position:
+class Position(metaclass=ExtendedType):
     """Represents the source code position of a IIR node in a source file."""
 
     _filename: Path
     _line: int
     _column: int
 
-    def __init__(self, filename: Path, line: int, column: int):
+    def __init__(self, filename: Path, line: int, column: int) -> None:
         self._filename = filename
         self._line = line
         self._column = column
@@ -70,32 +70,57 @@ class Position:
 
         return cls(Path(fileName), line, column)
 
-    @property
+    @readonly
     def Filename(self) -> Path:
+        """
+        Read-only property to access the filename this source code position referres to (:attr:`_filename`).
+
+        :returns: The source code position's filename.
+        """
         return self._filename
 
-    @property
+    @readonly
     def Line(self) -> int:
+        """
+        Read-only property to access the line number this source code position referres to (:attr:`_line`).
+
+        :returns: The source code position's line.
+        """
         return self._line
 
-    @property
+    @readonly
     def Column(self) -> int:
+        """
+        Read-only property to access the column this source code position referres to (:attr:`_column`).
+
+        :returns: The source code position's column.
+        """
         return self._column
 
     def __str__(self):
-        return "{file}:{line}:{column}".format(file=self._filename, line=self._line, column=self._column)
+        return f"{self._filename}:{self._line}:{self._column}"
 
 
 @export
-class DOMMixin:
+class DOMMixin(metaclass=ExtendedType, mixin=True):
     _iirNode: Iir
-    _position: Position = None
+    _position: Position
 
-    def __init__(self, node: Iir):
+    def __init__(self, node: Iir) -> None:
         self._iirNode = node
+        self._position = None
 
-    @property
+    # TODO: add Iir and Iir kind properties
+
+    @readonly
     def Position(self) -> Position:
+        """
+        Cached read-only property to access an IIR's position in source code (:attr:`_position`).
+
+        If :attr:`_position` is None, resolve the position object from :attr:`_iirNode`
+
+        :returns: The IIR's position in the source file.
+        """
         if self._position is None:
             self._position = Position.parse(self._iirNode)
 
