@@ -27,32 +27,34 @@ class Msgid(IntEnum):
     Warnid_Reserved_Word = 8
     Warnid_Pragma = 9
     Warnid_Nested_Comment = 10
-    Warnid_Directive = 11
-    Warnid_Parenthesis = 12
-    Warnid_Vital_Generic = 13
-    Warnid_Delayed_Checks = 14
+    Warnid_Parenthesis = 11
+    Warnid_Vital_Generic = 12
+    Warnid_Delayed_Checks = 13
+    Warnid_Sensitivity = 14
     Warnid_Body = 15
     Warnid_Specs = 16
     Warnid_Universal = 17
     Warnid_Port_Bounds = 18
     Warnid_Runtime_Error = 19
     Warnid_Delta_Cycle = 20
-    Warnid_No_Wait = 21
+    Warnid_Missing_Wait = 21
     Warnid_Shared = 22
     Warnid_Hide = 23
     Warnid_Unused = 24
     Warnid_Nowrite = 25
-    Warnid_Others = 26
-    Warnid_Pure = 27
-    Warnid_Analyze_Assert = 28
-    Warnid_Attribute = 29
-    Warnid_Useless = 30
-    Warnid_No_Assoc = 31
-    Warnid_Conformance = 32
-    Warnid_Unkept_Attribute = 33
-    Warnid_Unhandled_Attribute = 34
-    Warnid_Static = 35
-    Warnid_Elaboration = 36
-    Msgid_Warning = 37
-    Msgid_Error = 38
-    Msgid_Fatal = 39
+    Warnid_Logic_Loop = 26
+    Warnid_Others = 27
+    Warnid_Pure = 28
+    Warnid_Analyze_Assert = 29
+    Warnid_Attribute = 30
+    Warnid_Useless = 31
+    Warnid_Missing_Assoc = 32
+    Warnid_Open_Assoc = 33
+    Warnid_Conformance = 34
+    Warnid_Unkept_Attribute = 35
+    Warnid_Unhandled_Attribute = 36
+    Warnid_Static = 37
+    Warnid_Elaboration = 38
+    Msgid_Warning = 39
+    Msgid_Error = 40
+    Msgid_Fatal = 41
