@@ -73,7 +73,7 @@ class ParseError(Exception):
         self.msg = msg
 
     def __str__(self):
-        return ("Parse error at {lr.filename}:{lr.lineno}: {msg}".format(lr=self.lr, msg=self.msg))
+        return f"Parse error at {self.lr.filename}:{self.lr.lineno}: {self.msg}"
 
 
 # Return fields description.
@@ -95,7 +95,7 @@ def read_fields(file):
 
     # Read formats
     l = lr.get()
-    pat_field_name = re.compile("      Format_(\w+),?\n")
+    pat_field_name = re.compile(r"      Format_(\w+),?\n")
     while l != "     );\n":
         m = pat_field_name.match(l)
         if m is None:
@@ -108,8 +108,8 @@ def read_fields(file):
 
     # Read fields
     l = lr.get()
-    pat_fields = re.compile("   -- Fields of Format_(\w+):\n")
-    pat_field_desc = re.compile("   --   (\w+) : (\w+).*\n")
+    pat_fields = re.compile(r"   -- Fields of Format_(\w+):\n")
+    pat_field_desc = re.compile(r"   --   (\w+) : (\w+).*\n")
     common_desc = {}
 
     # Read until common fields.
@@ -168,8 +168,8 @@ def read_kinds(filename):
         raise ParseError(lr, 'no open parenthesis after "type ' + type_name + '"')
 
     # Read literals
-    pat_node = re.compile("      " + prefix_name + "(\w+),?( +-- .*)?\n")
-    pat_comment = re.compile("( +-- .*)?\n")
+    pat_node = re.compile("      " + prefix_name + r"(\w+),?( +-- .*)?\n")
+    pat_comment = re.compile(r"( +-- .*)?\n")
     while True:
         l = lr.get()
         if l == "     );\n":
@@ -319,16 +319,16 @@ def read_methods(filename):
 #  (one description may describe several nodes).
 # A comment start at column 2 or 4 or later.
 def read_nodes_fields(lr, names, fields, nodes, funcs_dict):
-    pat_only = re.compile("   -- Only for " + prefix_name + "(\w+):\n")
-    pat_only_bad = re.compile("   -- *Only for.*\n")
-    pat_field = re.compile("   --   Get/Set_(\w+) \((Alias )?([\w,]+)\)\n")
-    pat_comment = re.compile("   --(|  [^ ].*|    .*)\n")
+    pat_only = re.compile(r"   -- Only for " + prefix_name + r"(\w+):\n")
+    pat_only_bad = re.compile(r"   -- *Only for.*\n")
+    pat_field = re.compile(r"   --   Get/Set_(\w+) \((Alias )?([\w,]+)\)\n")
+    pat_comment = re.compile(r"   --(|  [^ ].*|    .*)\n")
 
     # Create nodes
     cur_nodes = []
     for (nm, fmt) in names:
         if fmt not in fields:
-            raise ParseError(lr, 'unknown format "{}"'.format(fmt))
+            raise ParseError(lr, f'unknown format "{fmt}"')
         n = NodeDesc(nm, fmt, {x: None for x in fields[fmt]}, {})
         nodes[nm] = n
         cur_nodes.append(n)
@@ -412,10 +412,10 @@ def read_nodes(filename, kinds, kinds_ranges, fields, funcs):
     while lr.get() != "   -- Start of " + type_name + ".\n":
         pass
 
-    pat_decl = re.compile("   -- " + prefix_name + "(\w+) \((\w+)\)\n")
-    pat_decls = re.compile("   -- " + prefix_range_name + "(\w+) \((\w+)\)\n")
-    pat_comment_line = re.compile("   --+\n")
-    pat_comment_box = re.compile("   --(  .*)?\n")
+    pat_decl = re.compile(r"   -- " + prefix_name + r"(\w+) \((\w+)\)\n")
+    pat_decls = re.compile(r"   -- " + prefix_range_name + r"(\w+) \((\w+)\)\n")
+    pat_comment_line = re.compile(r"   --+\n")
+    pat_comment_box = re.compile(r"   --(  .*)?\n")
     while True:
         l = lr.get()
         if l == "   -- End of " + type_name + ".\n":
@@ -872,6 +872,76 @@ def do_meta_body():
             print(l)
 
 
+def read_enum(filename, type_name, prefix, g=lambda m: m.group(1)):
+    """Read an enumeration declaration :param type_name:
+    from :param filename:."""
+    pat_decl = re.compile(r"   type {0} is$".format(type_name))
+    pat_enum = re.compile(r"      {0}(\w+),?( *-- .*)?$".format(prefix))
+    pat_comment = re.compile(r" *-- .*$")
+    lr = linereader(filename)
+    while not pat_decl.match(lr.get()):
+        pass
+    line = lr.get()
+    if line != "     (\n":
+        raise ParseError(lr, f"{filename}:{lr.lineno}: missing open parenthesis")
+    toks = []
+    while True:
+        line = lr.get()
+        if line == "     );\n":
+            break
+        m = pat_enum.match(line)
+        if m:
+            toks.append(g(m))
+        elif pat_comment.match(line):
+            pass
+        elif line == "\n":
+            pass
+        else:
+            print(line, file=sys.stderr)
+            raise ParseError(
+                lr,
+                f"{filename}:{ lr.lineno}: incorrect line in enum {type_name}"
+            )
+    return toks
+
+def read_std_names():
+    pat_name_first = re.compile(r"   Name_(\w+)\s+: constant Name_Id := (\d+);")
+    pat_name_def = re.compile(r"   Name_(\w+)\s+:\s+constant Name_Id :=\s+Name_(\w+)( \+ (\d+))?;")
+    dict = {}
+    lr = linereader("../std_names.ads")
+    while True:
+        line = lr.get()
+        m = pat_name_first.match(line)
+        if m:
+            name_def = m.group(1)
+            val = int(m.group(2))
+            dict[name_def] = val
+            res = [(name_def, val)]
+            break
+    val_max = 1
+    while True:
+        line = lr.get()
+        if line == "end Std_Names;\n":
+            break
+        if line.endswith(":=\n"):
+            line = line.rstrip() + lr.get()
+        m = pat_name_def.match(line)
+        if m:
+            name_def = m.group(1)
+            name_ref = m.group(2)
+            val = m.group(4)
+            if not val:
+                val = 0
+            val_ref = dict.get(name_ref, None)
+            if not val_ref:
+                raise ParseError(lr, f"name {name_ref} not found")
+            val = val_ref + int(val)
+            val_max = max(val_max, val)
+            dict[name_def] = val
+            res.append((name_def, val))
+    return res
+
+
 actions = {
     "disp-nodes": do_disp_nodes,
     "disp-kinds": do_disp_kinds,
