@@ -17,17 +17,17 @@ libname = "libghdl"
 
 
 def print_enum(name, vals):
-    print(dedent("""
+    print(dedent(f"""
 
         @export
         @unique
-        class {0}(IntEnum):
-        """).format(name), end=''
+        class {name}(IntEnum):
+        """), end=''
     )
     for n, k in enumerate(vals):
         if k == "None":
             k = "PNone"
-        print("    {0} = {1}".format(k, n))
+        print(f"    {k} = {n}")
 
 
 def print_file_header(includeIntEnumUnique=True, includeBindToLibGHDL=True):
@@ -36,8 +36,8 @@ def print_file_header(includeIntEnumUnique=True, includeBindToLibGHDL=True):
             # Call 'make' in 'src/vhdl' to regenerate:
             #
         """) + "{sysImports}from pyTooling.Decorators import export\n{moduleImports}".format(
-            sysImports = "from enum import IntEnum, unique\n" if includeIntEnumUnique else "",
-            moduleImports = "\nfrom pyGHDL.libghdl._decorator import BindToLibGHDL\n" if includeBindToLibGHDL else "",
+            sysImports="from enum import IntEnum, unique\n" if includeIntEnumUnique else "",
+            moduleImports="\nfrom pyGHDL.libghdl._decorator import BindToLibGHDL\n" if includeBindToLibGHDL else "",
         )
     )
 
@@ -51,29 +51,29 @@ def do_class_kinds():
         """), end=''
     )
     for k, v in pnodes.kinds_ranges.items():
-        print("    {0} = [".format(k))
+        print(f"    {k} = [")
         for e in v:
-            print("        Iir_Kind.{},".format(e))
+            print(f"        Iir_Kind.{e},")
         print("    ]")
         print()
 
 
 def do_iirs_subprg():
     classname = "vhdl__nodes"
-    print(dedent("""
+    print(dedent(f"""
 
         @export
         @BindToLibGHDL("{classname}__get_kind")
         def Get_Kind(node: Iir) -> IirKind:
             \"\"\"Get node kind.\"\"\"
-            return 0
+            return 0  # pragma: no cover
 
         @export
         @BindToLibGHDL("{classname}__get_location")
         def Get_Location(node: Iir) -> LocationType:
             \"\"\"\"\"\"
-            return 0
-        """).format(libname=libname, classname=classname)
+            return 0  # pragma: no cover
+        """)
     )
     for k in pnodes.funcs:
         # Don't use the Iir_* subtypes (as they are not described).
@@ -82,18 +82,17 @@ def do_iirs_subprg():
         if rtype == "TokenType":
             rtype = "Tok"
 
-        print(dedent("""
+        print(dedent(f"""
             @export
-            @BindToLibGHDL("{classname}__get_{kname_lower}")
-            def Get_{kname}(obj: Iir) -> {rtype}:
+            @BindToLibGHDL("{classname}__get_{k.name.lower()}")
+            def Get_{k.name}(obj: Iir) -> {rtype}:
                 \"\"\"\"\"\"
-                return 0
+                return 0  # pragma: no cover
             @export
-            @BindToLibGHDL("{classname}__set_{kname_lower}")
-            def Set_{kname}(obj: Iir, value: {rtype}) -> None:
+            @BindToLibGHDL("{classname}__set_{k.name.lower()}")
+            def Set_{k.name}(obj: Iir, value: {rtype}) -> None:
                 \"\"\"\"\"\"
-            """).format(kname=k.name, kname_lower=k.name.lower(), rtype=rtype,
-                         libname=libname, classname=classname)
+            """)
         )
 
 
@@ -103,14 +102,14 @@ def do_libghdl_elocations():
     print("from pyGHDL.libghdl import libghdl")
     print()
     for k in pnodes.funcs:
-        print(dedent("""
+        print(dedent(f"""
             @export
-            def Get_{kname}(obj):
-                return {libname}.{classname}__get_{kname_lower}(obj)
+            def Get_{k.name}(obj):
+                return {libname}.{classname}__get_{k.name.lower()}(obj)
             @export
-            def Set_{kname}(obj, value) -> None:
-                {libname}.{classname}__set_{kname_lower}(obj, value)
-            """).format(kname=k.name, kname_lower=k.name.lower(), libname=libname, classname=classname)
+            def Set_{k.name}(obj, value) -> None:
+                {libname}.{classname}__set_{k.name.lower()}(obj, value)
+            """)
         )
 
 
@@ -121,22 +120,22 @@ def do_class_types():
 def do_types_subprg():
     print()
     for k in pnodes.get_types():
-        print(dedent("""
-            def Get_{0}(node, field):
-                return {1}.vhdl__nodes_meta__get_{2}(node, field)
-            """).format(k, libname, k.lower())
+        print(dedent(f"""
+            def Get_{k}(node, field):
+                return {libname}.vhdl__nodes_meta__get_{k.lower()}(node, field)
+            """)
         )
 
 
 def do_has_subprg():
     print()
     for f in pnodes.funcs:
-        print(dedent("""
+        print(dedent(f"""
             @export
-            @BindToLibGHDL("vhdl__nodes_meta__has_{fname_lower}")
-            def Has_{fname}(kind: IirKind) -> bool:
+            @BindToLibGHDL("vhdl__nodes_meta__has_{f.name.lower()}")
+            def Has_{f.name}(kind: IirKind) -> bool:
                 \"\"\"\"\"\"
-            """).format(fname=f.name, libname=libname, fname_lower=f.name.lower())
+            """)
         )
 
 
@@ -148,45 +147,10 @@ def do_class_fields():
     print_enum("fields", [f.name for f in pnodes.funcs])
 
 
-def read_enum(filename, type_name, prefix, class_name, g=lambda m: m.group(1)):
-    """Read an enumeration declaration from :param filename:."""
-    pat_decl = re.compile(r"   type {0} is$".format(type_name))
-    pat_enum = re.compile(r"      {0}(\w+),?( *-- .*)?$".format(prefix))
-    pat_comment = re.compile(r" *-- .*$")
-    lr = pnodes.linereader(filename)
-    while not pat_decl.match(lr.get()):
-        pass
-    line = lr.get()
-    if line != "     (\n":
-        raise pnodes.ParseError(
-            lr, "{}:{}: missing open parenthesis".format(filename, lr.lineno)
-        )
-    toks = []
-    while True:
-        line = lr.get()
-        if line == "     );\n":
-            break
-        m = pat_enum.match(line)
-        if m:
-            toks.append(g(m))
-        elif pat_comment.match(line):
-            pass
-        elif line == "\n":
-            pass
-        else:
-            print(line, file=sys.stderr)
-            raise pnodes.ParseError(
-                lr,
-                "{}:{}: incorrect line in enum {}".format(
-                    filename, lr.lineno, type_name
-                ),
-            )
-    print_enum(class_name, toks)
-
-
 def read_spec_enum(type_name, prefix, class_name):
     """Read an enumeration declaration from iirs.ads."""
-    read_enum(pnodes.kind_file, type_name, prefix, class_name)
+    enum = pnodes.read_enum(pnodes.kind_file, type_name, prefix)
+    print_enum(class_name, enum)
 
 
 def do_libghdl_nodes():
@@ -215,7 +179,19 @@ def do_libghdl_nodes():
         )
         from pyGHDL.libghdl.vhdl.tokens import Tok
 
+        __all__ = [
+            "Null_Iir",
+            "Null_Iir_List",
+            "Iir_List_All",
+            "Null_Iir_Flist",
+            "Iir_Flist_Others",
+            "Iir_Flist_All",
+        ]
+
         Null_Iir = 0
+        \"\"\"
+        Null element for an IIR node reference.
+        \"\"\"
 
         Null_Iir_List = 0
         Iir_List_All = 1
@@ -262,7 +238,7 @@ def do_libghdl_meta():
 
             :param K: Node to get first array index from.
             \"\"\"
-            return 0
+            return 0  # pragma: no cover
 
 
         @export
@@ -279,13 +255,13 @@ def do_libghdl_meta():
 
             :param K: Node to get last array index from.
             \"\"\"
-            return 0
+            return 0  # pragma: no cover
 
         @export
         @BindToLibGHDL("vhdl__nodes_meta__get_field_by_index")
         def get_field_by_index(K: IirKind) -> int:
             \"\"\"\"\"\"
-            return 0
+            return 0  # pragma: no cover
 
         @export
         def get_field_type(*args):
@@ -305,40 +281,7 @@ def do_libghdl_meta():
 
 
 def do_libghdl_names():
-    pat_name_first = re.compile(r"   Name_(\w+)\s+: constant Name_Id := (\d+);")
-    pat_name_def = re.compile(r"   Name_(\w+)\s+:\s+constant Name_Id :=\s+Name_(\w+)( \+ (\d+))?;")
-    dict = {}
-    lr = pnodes.linereader("../std_names.ads")
-    while True:
-        line = lr.get()
-        m = pat_name_first.match(line)
-        if m:
-            name_def = m.group(1)
-            val = int(m.group(2))
-            dict[name_def] = val
-            res = [(name_def, val)]
-            break
-    val_max = 1
-    while True:
-        line = lr.get()
-        if line == "end Std_Names;\n":
-            break
-        if line.endswith(":=\n"):
-            line = line.rstrip() + lr.get()
-        m = pat_name_def.match(line)
-        if m:
-            name_def = m.group(1)
-            name_ref = m.group(2)
-            val = m.group(4)
-            if not val:
-                val = 0
-            val_ref = dict.get(name_ref, None)
-            if not val_ref:
-                raise pnodes.ParseError(lr, "name {0} not found".format(name_ref))
-            val = val_ref + int(val)
-            val_max = max(val_max, val)
-            dict[name_def] = val
-            res.append((name_def, val))
+    res = pnodes.read_std_names()
     print_file_header(includeIntEnumUnique=False, includeBindToLibGHDL=False)
     print(dedent("""
 
@@ -351,12 +294,13 @@ def do_libghdl_names():
         # Avoid clash with Python names
         if n in ["False", "True", "None"]:
             n = "N" + n
-        print("    {0} = {1}".format(n, v))
+        print(f"    {n} = {v}")
 
 
 def do_libghdl_tokens():
     print_file_header(includeBindToLibGHDL=False)
-    read_enum("vhdl-tokens.ads", "Token_Type", "Tok_", "Tok")
+    enum = pnodes.read_enum("vhdl-tokens.ads", "Token_Type", "Tok_")
+    print_enum("Tok", enum)
 
 
 def do_libghdl_errorout():
@@ -369,13 +313,13 @@ def do_libghdl_errorout():
         """), end=''
     )
 
-    read_enum(
+    enum = pnodes.read_enum(
         "../errorout.ads",
         "Msgid_Type",
         "(Msgid|Warnid)_",
-        "Msgid",
         g=lambda m: m.group(1) + "_" + m.group(2),
     )
+    print_enum("Msgid", enum)
 
 
 pnodes.actions.update(
