@@ -27,7 +27,7 @@
 #include <signal.h>
 #include <fcntl.h>
 
-#if ( defined (__linux__) || defined (__APPLE__) ) && !defined (__ANDROID__)
+#if ( (defined (__linux__) && defined (__GLIBC__) ) || defined (__APPLE__) ) && !defined (__ANDROID__)
 #define HAVE_BACKTRACE 1
 #include <sys/ucontext.h>
 #endif
@@ -79,6 +79,10 @@ static JMP_BUF run_env;
 #define NEED_SIGBUS_HANDLER
 #endif
 
+#if defined (__linux__) && defined (__x86_64__)
+#define NEED_SIGFPE_HANDLER
+#endif
+
 static struct sigaction prev_sigsegv_act;
 
 #ifdef NEED_SIGFPE_HANDLER
