@@ -2,7 +2,7 @@
 
 . ../../testenv.sh
 
-analyze std_logic_warning.vhdl
+analyze --std=93 std_logic_warning.vhdl
 #elab_simulate warning_test
 
 analyze test.vhdl
