@@ -2,7 +2,8 @@
 
 . ../../testenv.sh
 
-analyze_failure bug.vhdl
+analyze bug.vhdl
+elab_simulate_failure bug
 
 analyze bug2.vhdl
 elab_simulate_failure bug
