@@ -9,7 +9,8 @@ elab design_tb
 
 if ghdl_has_feature design_tb ghw; then
   simulate design_tb --wave=tb.ghw
-  rm -f tb.ghw
+  ghw_diff tb
+  rm -f tb.txt tb.ghw
 fi
 
 clean
