@@ -4,7 +4,7 @@
 
 analyze bug.vhdl
 elab_simulate bug > out.txt 2> err.txt
-diff_nocr -q out.txt out.ref
+diff_nocr out.txt out.ref
 
 rm -f out.txt err.txt
 clean
