@@ -9,7 +9,7 @@ elab wb_demux_tb
 if ghdl_has_feature wb_demux_tb ghw; then
   simulate wb_demux_tb --trace-signals | 
     grep wb_demux_tb | cut -d ' ' -f 1,3- > tb.out
-  diff --strip-trailing-cr tb.out tb.ref
+  diff_nocr tb.out tb.ref
 fi
 
 rm -f tb.out
