@@ -3,7 +3,7 @@
 . ../../testenv.sh
 
 analyze tb.vhdl 2> tb.out
-diff_nocr -q tb.ref tb.out
+diff_nocr tb.ref tb.out
 
 rm -f tb.out
 clean
