@@ -1,8 +1,8 @@
 #include <stdio.h>
 #include <vpi_user.h>
 
-void
-vpi_proc (void)
+PLI_INT32
+vpi_proc (s_cb_data *cb)
 {
   vpiHandle net;
   s_vpi_value val;
@@ -11,11 +11,12 @@ vpi_proc (void)
   if (net == NULL)
     {
       printf ("cannot get net\n");
-      return;
+      return -1;
     }
   val.format = vpiBinStrVal;
   vpi_get_value (net, &val);
   printf ("value: %s\n", val.value.str);
+  return 0;
 }
 
 void my_handle_register()
