@@ -5,8 +5,8 @@
 analyze ent.vhdl
 elab_simulate ent
 
-if "$GHDL" -v | egrep -q 'mcode|interpret'; then
-  echo "Option -o not supported by mcode/interpretation"
+if "$GHDL" -v | egrep -q 'JIT code'; then
+  echo "Option -o not supported by JIT"
 else
   "$GHDL" --elab-run -o ent1 ent
   "$GHDL" --elab-run -o "$PWD/ent2" ent
