@@ -34,9 +34,10 @@ import ctypes
 from inspect import currentframe
 from pathlib import Path
 from textwrap import dedent
-from typing import TypeVar, Dict
+from typing import TypeVar, Dict, cast
 from unittest import TestCase
 
+from pyTooling.Common import firstValue
 
 from pyGHDL.dom import Expression
 from pyGHDL.dom.NonStandard import Design, Document
@@ -52,13 +53,6 @@ if __name__ == "__main__":
     exit(1)
 
 
-_DictKey = TypeVar("_DictKey")
-_DictValue = TypeVar("_DictValue")
-
-def firstValue(d: Dict[_DictKey, _DictValue]) -> _DictValue:
-    return next(iter(d.values()))
-
-
 class Expressions(TestCase):
     _root = Path(__file__).resolve().parent.parent
     _design = Design()
@@ -84,12 +78,10 @@ class Expressions(TestCase):
         return default
 
     def test_NotExpression(self):
-        filename: Path = self._root / "{className}_{funcName}.vhdl".format(
-            className=self.__class__.__name__, funcName= currentframe().f_code.co_name[5:]
-        )
+        filename: Path = self._root / f"{self.__class__.__name__}_{currentframe().f_code.co_name[5:]}.vhdl"
 
         # Define test data
-        constantDeclartion = "constant c0 : boolean := not true;"
+        constantDeclartion = "constant c0 : boolean := not True;"
 
         # Parse in-memory
         default: Expression = self.parse(filename, constantDeclartion)
@@ -97,7 +89,7 @@ class Expressions(TestCase):
         # Start checks
         self.assertIsInstance(default, InverseExpression)
         self.assertIsInstance(default.Operand, SimpleObjectOrFunctionCallSymbol)
-        self.assertEqual("true", str(default.Operand))  # .SymbolName))  # XXX: hacked
+        self.assertEqual("True", cast(SimpleObjectOrFunctionCallSymbol, default.Operand).Name.Identifier)
 
     # def test_AbsExpression(self):
     #     filename: Path = self._root / "{className}_{funcName}.vhdl".format(
