@@ -3,8 +3,7 @@
 . ../../testenv.sh
 
 GHDL_STD_FLAGS=--std=08
-synth cpu.vhdl -e $t > syn_cpu.vhdl
-analyze syn_cpu.vhdl
+synth_analyze cpu
 clean
 
 echo "Test successful"
